@@ -18,7 +18,7 @@ PbPb.normal.ratios <- function(x){
         E11 <- x$x[,'errPb204Pb206']^2
         E22 <- x$x[,'errPb207Pb206']^2
         E12 <- x$x[,'rho']*x$x[,'errPb204Pb206']*x$x[,'errPb207Pb206']
-        covmat <- errorprop(J11,J12,J21,J22,E11,E12,E22)
+        covmat <- errorprop(J11,J12,J21,J22,E11,E22,E12)
         errPb206Pb204 <- sqrt(covmat[,'varX'])
         errPb207Pb204 <- sqrt(covmat[,'varY'])
         rho <- covmat[,'cov']/(errPb206Pb204*errPb207Pb204)
@@ -34,7 +34,7 @@ PbPb.normal.ratios <- function(x){
         E12 <- get.cov.div(x$x[,'Pb207Pb204'],x$x[,'errPb207Pb204'],
                            x$x[,'Pb206Pb204'],x$x[,'errPb206Pb204'],
                            x$x[,'Pb207Pb206'],x$x[,'errPb207Pb206'])
-        covmat <- errorprop(J11,J12,J21,J22,E11,E12,E22)
+        covmat <- errorprop(J11,J12,J21,J22,E11,E22,E12)
         errPb206Pb204 <- x$x[,'errPb206Pb204']
         errPb207Pb204 <- x$x[,'errPb207Pb204']
         rho <- covmat[,'cov']/(errPb206Pb204*errPb207Pb204)
@@ -42,6 +42,7 @@ PbPb.normal.ratios <- function(x){
     out <- cbind(Pb206Pb204,errPb206Pb204,Pb207Pb204,errPb207Pb204,rho)
     colnames(out) <- c('Pb206Pb204','errPb206Pb204',
                        'Pb207Pb204','errPb207Pb204','rho')
+    out[abs(out[,'rho'])>1,'rho'] <- 0.99 # protect against rounding errors
     out
 }
 # returns ratios, errors and correlations
@@ -58,7 +59,7 @@ PbPb.inverse.ratios <- function(x){
         E11 <- x$x[,'errPb206Pb204']^2
         E22 <- x$x[,'errPb207Pb204']^2
         E12 <- x$x[,'rho']*x$x[,'errPb206Pb204']*x$x[,'errPb207Pb204']
-        covmat <- errorprop(J11,J12,J21,J22,E11,E12,E22)
+        covmat <- errorprop(J11,J12,J21,J22,E11,E22,E12)
         errPb204Pb206 <- sqrt(covmat[,'varX'])
         errPb207Pb206 <- sqrt(covmat[,'varY'])
         rho <- covmat[,'cov']/(errPb204Pb206*errPb207Pb206)
@@ -80,7 +81,7 @@ PbPb.inverse.ratios <- function(x){
         E12 <- get.cov.mult(x$x[,'Pb206Pb204'],x$x[,'errPb206Pb204'],
                             x$x[,'Pb207Pb206'],x$x[,'errPb207Pb206'],
                             x$x[,'Pb207Pb204'],x$x[,'errPb207Pb204'])
-        covmat <- errorprop(J11,J12,J21,J22,E11,E12,E22)
+        covmat <- errorprop(J11,J12,J21,J22,E11,E22,E12)
         errPb204Pb206 <- sqrt(covmat[,'varX'])
         errPb207Pb206 <- x$x[,'errPb207Pb206']
         rho <- covmat[,'cov']/(errPb204Pb206*errPb207Pb206)
@@ -88,17 +89,13 @@ PbPb.inverse.ratios <- function(x){
     out <- cbind(Pb204Pb206,errPb204Pb206,Pb207Pb206,errPb207Pb206,rho)
     colnames(out) <- c('Pb204Pb206','errPb204Pb206',
                        'Pb207Pb206','errPb207Pb206','rho')
+    out[abs(out[,'rho'])>1,'rho'] <- 0.99 # protect against rounding errors
     out
 }
 
-PbPb.age <- function(x,exterr=TRUE,i=NA,sigdig=NA,i2i=TRUE,...){
+PbPb.age <- function(x,exterr=TRUE,i=NA,sigdig=NA,...){
     ns <- length(x)
     dat <- data2york(x,inverse=FALSE)
-    if (i2i){
-        fit <- isochron(x,plot=FALSE,exterr=exterr)        
-        dat[,'Y'] <- dat[,'Y'] - fit$a[1]
-        if (exterr) dat[,'sY'] <- sqrt(dat[,'sY']^2 + fit$a[2]^2)
-    }
     out <- matrix(0,ns,2)
     colnames(out) <- c('t','s[t]')
     E <- matrix(0,2,2)
