@@ -267,13 +267,28 @@ age_to_Pb207Pb206_ratio <- function(tt,st=0){
     out
 }
 
+get.Pb204U238.ratios <- function(x){
+    labels <- c('Pb204U238','errPb204U238')
+    if (x$format < 4) stop('No 204Pb measurements available!')
+    else if (x$format %in% c(4,6)){
+        out <- subset(x$x,select=labels)
+    } else {
+        Pb204U238 <- x$x[,'Pb204Pb206']/x$x[,'U238Pb206']
+        errPb204U238 <-
+            Pb204U238*sqrt( (x$x[,'errPb204Pb206']/x$x[,'Pb204Pb206'])^2 +
+                            (x$x[,'errU238Pb206']/x$x[,'U238Pb206'])^2 )
+        out <- cbind(Pb204U238,errPb204U238)
+    }
+    colnames(out) <- labels
+    out
+}
 get.Pb207U235.ratios <- function(x,exterr=FALSE){
     ns <- length(x)
     out <- matrix(0,ns,2)
     labels <- c('Pb207U235','errPb207U235')
     colnames(out) <- labels
     if (x$format %in% c(1,3,4,6)){
-        out <- x$x[,labels]
+        out <- subset(x$x,select=labels)
     } else if (x$format %in% c(2,5)){
         R <- iratio('U238U235')[1]
         sR <- iratio('U238U235')[2]
@@ -296,7 +311,7 @@ get.Pb206U238.ratios <- function(x){
     labels <- c('Pb206U238','errPb206U238')
     colnames(out) <- labels
     if (x$format %in% c(1,3,4,6)){
-        out <- x$x[,labels]
+        out <- subset(x$x,select=labels)
     } else if (x$format %in% c(2,5)){
         out[,'Pb206U238'] <- 1/x$x[,'U238Pb206']
         out[,'errPb206U238'] <- out[,'Pb206U238']*
@@ -314,7 +329,7 @@ get.U238Pb206.ratios <- function(x){
         out[,'errU238Pb206'] <- out[,'U238Pb206']*
             x$x[,'errPb206U238']/x$x[,'Pb206U238']
     } else if (x$format %in% c(2,5)){
-        out <- x$x[,labels]
+        out <- subset(x$x,select=labels)
     }
     out
 }
@@ -337,7 +352,7 @@ get.Pb207Pb206.ratios <- function(x,exterr=FALSE){
         if (exterr) relerr2 <- relerr2 + (sR/R)^2
         out[,'errPb207Pb206'] <- sqrt(relerr2)*out[,'Pb207Pb206']
     } else if (x$format %in% c(2,3,5,6)){
-        out <- x$x[,labels]
+        out <- subset(x$x,select=labels)
     }
     out
 }
@@ -559,136 +574,3 @@ filter.UPb.ages <- function(x,type=4,cutoff.76=1100,
     colnames(out) <- c('t','s[t]')
     out
 }
-
-# option = 1: Stacey-Kramers
-# option = 2: isochron
-# option = 3: assumed Pb-composition
-common.Pb.correction <- function(x,option=1){
-    ns <- length(x)
-    if (option == 1) out <- common.Pb.stacey.kramers(x)
-    else if (option == 2) out <- common.Pb.isochron(x)
-    else if (option == 3) out <- common.Pb.nominal(x)
-    else out <- x
-    out$x.raw <- x$x
-    out
-}
-common.Pb.isochron <- function(x){
-    if (x$format<4){
-        d <- data2york(x,wetherill=FALSE)
-        fit <- york(d)
-        i76 <- fit$a[1]
-    } else {
-        lud <- ludwig(x)
-        i64 <- lud$par['64i']
-        i74 <- lud$par['74i']
-    }
-    if (x$format < 4)
-        out <- Pb.correction.without.204(x,i76)
-    else
-        out <- Pb.correction.with.204(x,i64,i74)
-    out
-}
-common.Pb.stacey.kramers <- function(x){
-    sk.206.204 <- 11.152
-    sk.207.204 <- 12.998
-    sk.238.204 <- 9.74
-    U238U235 <- settings('iratio','U238U235')[1]
-    l5 <- lambda('U235')[1]
-    l8 <- lambda('U238')[1]
-    ti <- 3700
-    tt <- 1000
-    for (i in 1:5){
-        i64 <- sk.206.204 + sk.238.204*(exp(l8*(ti-tt))-1)
-        i74 <- sk.207.204 + sk.238.204*(exp(l5*(ti-tt))-1)/U238U235
-        if (x$format < 4)
-            out <- Pb.correction.without.204(x,i74/i64)
-        else
-            out <- Pb.correction.with.204(x,i64,i74)
-        tt <- get.Pb206U238.age(out)[,1]
-    }
-    out
-}
-common.Pb.nominal <- function(x){
-    i64 <- settings('iratio','Pb206Pb204')[1]
-    i74 <- settings('iratio','Pb207Pb204')[1]
-    if (x$format < 4)
-        out <- Pb.correction.without.204(x,i74/i64)
-    else
-        out <- Pb.correction.with.204(x,i64,i74)
-    out
-}
-Pb.correction.without.204 <- function(x,i76){
-    ns <- length(x)
-    ni <- length(i76)
-    out <- x
-    m76 <- get.Pb207Pb206.ratios(x)[,1]
-    m86 <- get.U238Pb206.ratios(x)[,1]
-    tint <- rep(0,ns) # intercept age
-    for (i in 1:ns){
-        if (ni>1)
-            tint[i] <- project.concordia(m76[i],m86[i],i76[i])
-        else
-            tint[i] <- project.concordia(m76[i],m86[i],i76)
-    }
-    if (x$format == 1){
-        out$x[,'Pb207U235'] <- age_to_Pb207U235_ratio(tint)[,'75']
-        out$x[,'errPb207U235'] <- x$x[,'errPb207U235']
-        out$x[,'Pb206U238'] <- age_to_Pb206U238_ratio(tint)[,'68']
-        out$x[,'errPb206U238'] <- x$x[,'errPb206U238']
-        out$x[,'rhoXY'] <- x$x[,'rhoXY']        
-    } else if (x$format == 2){
-        out$x[,'U238Pb206'] <- age_to_U238Pb206_ratio(tint)[,'86']
-        out$x[,'errU238Pb206'] <- x$x[,'errU238Pb206']
-        out$x[,'Pb207Pb206'] <- age_to_Pb207Pb206_ratio(tint)[,'76']
-        out$x[,'errPb207Pb206'] <- x$x[,'errPb207Pb206']
-        out$x[,'rhoXY'] <- x$x[,'rhoXY']
-    } else if (x$format == 3){
-        out$x[,'Pb207Pb206'] <- age_to_Pb207Pb206_ratio(tint)[,'76']
-        out$x[,'errPb207Pb206'] <- x$x[,'errPb207Pb206']
-        out$x[,'Pb207U235'] <- age_to_Pb207U235_ratio(tint)[,'75']
-        out$x[,'errPb207U235'] <- x$x[,'errPb207U235']
-        out$x[,'Pb206U238'] <- age_to_Pb206U238_ratio(tint)[,'68']
-        out$x[,'errPb206U238'] <- x$x[,'errPb206U238']
-    }
-    out
-}
-Pb.correction.with.204 <- function(x,i64,i74){
-    ns <- length(x)
-    out <- x
-    U238U235 <- settings('iratio','U238U235')[1]
-    if (x$format == 4){
-        out$x <- matrix(0,ns,5)
-        colnames(out$x) <- c('Pb207U235','errPb207U235','Pb206U238','errPb206U238','rhoXY')
-        out$x[,'Pb207U235'] <- x$x[,'Pb207U235'] - i74*x$x[,'Pb204U238']*U238U235
-        out$x[,'errPb207U235'] <- x$x[,'errPb207U235']
-        out$x[,'Pb206U238'] <- x$x[,'Pb206U238'] - i64*x$x[,'Pb204U238']
-        out$x[,'errPb206U238'] <- x$x[,'errPb206U238']
-        out$x[,'rhoXY'] <- x$x[,'rhoXY']
-        out$format <- 1
-    } else if (x$format == 5){
-        out$x <- matrix(0,ns,5)
-        colnames(out$x) <- c('U238Pb206','errU238Pb206','Pb207Pb206','errPb207Pb206','rhoXY')
-        out$x[,'U238Pb206'] <- x$x[,'U238Pb206']/(1 - i64*x$x[,'Pb204Pb206'])
-        out$x[,'errU238Pb206'] <- x$x[,'errU238Pb206']
-        out$x[,'Pb207Pb206'] <-
-            (x$x[,'Pb207Pb206'] - x$x[,'Pb204Pb206']*i74)/(1 - x$x[,'Pb204Pb206']*i64)
-        out$x[,'errPb207Pb206'] <- x$x[,'errPb207Pb206']
-        out$x[,'rhoXY'] <- x$x[,'rhoXY']
-        out$format <- 2
-    } else if (x$format == 6){
-        out$x <- matrix(0,ns,9)
-        colnames(out$x) <- c('Pb207Pb206','errPb207Pb206',
-                             'Pb207U235','errPb207U235',
-                             'Pb206U238','errPb206U238',
-                             'rhoXY','rhoXZ','rhoYZ')
-        out$x[,'Pb207Pb206'] <-
-            (x$x[,'Pb207Pb206'] - x$x[,'Pb204Pb206']*i74)/(1 - x$x[,'Pb204Pb206']*i64)
-        out$x[,'errPb207Pb206'] <- x$x[,'errPb207Pb206']
-        out$x[,'Pb207U235'] <- x$x[,'Pb207U235'] - i74*x$x[,'Pb204U238']*U238U235
-        out$x[,'errPb207U235'] <- x$x[,'errPb207U235']
-        out$x[,'Pb206U238'] <- x$x[,'Pb206U238'] - i64*x$x[,'Pb204U238']
-        out$x[,'errPb206U238'] <- x$x[,'errPb206U238']
-        out$format <- 3
-    }
-    out
-}
