@@ -4,8 +4,34 @@
 #' display several estimates of the same quantity that have different
 #' standard errors.
 #'
-#' @param x Either an nx2 matix of (transformed) values z and their
-#'     standard errors s
+#' @details
+#'
+#' The radial plot (Galbraith, 1988, 1990) is a graphical device that
+#' was specifically designed to display heteroscedastic data, and is
+#' constructed as follows.  Consider a set of dates
+#' \eqn{\{t_1,...,t_i,...,t_n\}} and uncertainties
+#' \eqn{\{s[t_1],...,s[t_i],...,s[t_n]\}}. Define \eqn{z_i = z[t_i]}
+#' to be a transformation of \eqn{t_i} (e.g., \eqn{z_i = log[t_i]}),
+#' and let \eqn{s[z_i]} be its propagated analytical uncertainty
+#' (i.e., \eqn{s[z_i] = s[t_i]/t_i} in the case of a logarithmic
+#' transformation). Create a scatterplot of \eqn{(x_i,y_i)} values,
+#' where \eqn{x_i = 1/s[z_i]} and \eqn{y_i = (z_i-z_\circ)/s[z_i]},
+#' where \eqn{z_\circ} is some reference value such as the mean. The
+#' slope of a line connecting the origin of this scatterplot with any
+#' of the \eqn{(x_i,y_i)}s is proportional to \eqn{z_i} and, hence,
+#' the date \eqn{t_i}.  These dates can be more easily visualised by
+#' drawing a radial scale at some convenient distance from the origin
+#' and annotating it with labelled ticks at the appropriate
+#' angles. While the angular position of each data point represents
+#' the date, its horizontal distance from the origin is proportional
+#' to the precision. Imprecise measurements plot on the left hand side
+#' of the radial plot, whereas precise age determinations are found
+#' further towards the right. Thus, radial plots allow the observer to
+#' assess both the magnitude and the precision of quantitative data in
+#' one glance.
+#'
+#' @param x Either an \code{[n x 2]} matix of (transformed) values z
+#'     and their standard errors s
 #'
 #' OR
 #'
@@ -16,7 +42,7 @@
 #' @param to maximum age limit of the radial scale
 #' @param t0 central value
 #' @param transformation one of either \code{log}, \code{linear} or
-#'     (if \code{x} has class \code{fissiontracks})
+#'     (if \code{x} has class \code{fissiontracks}), \code{arcsin}.
 #' @param sigdig the number of significant digits of the numerical
 #'     values reported in the title of the graphical output.
 #' @param show.numbers boolean flag (\code{TRUE} to show grain
@@ -24,13 +50,14 @@
 #' @param pch plot character (default is a filled circle)
 #' @param levels a vector with additional values to be displayed as
 #'     different background colours of the plot symbols.
+#' @param clabel label of the colour legend
 #' @param bg a vector of two background colours for the plot symbols.
-#'     If \code{levels=NA}, then only the first colour will be
-#'     used. If \code{levels} is a vector of numbers, then \code{bg}
-#'     is used to construct a colour ramp.
+#'     If \code{levels=NA}, then only the first colour is used. If
+#'     \code{levels} is a vector of numbers, then \code{bg} is used to
+#'     construct a colour ramp.
 #' @param title add a title to the plot?
 #' @param k number of peaks to fit using the finite mixture models of
-#'     Galbraith and Green (1993). Setting \code{k='auto'}
+#'     Galbraith and Laslett (1993). Setting \code{k='auto'}
 #'     automatically selects an optimal number of components based on
 #'     the Bayes Information Criterion (BIC). Setting \code{k='min'}
 #'     estimates the minimum value using a three parameter model
@@ -41,13 +68,26 @@
 #' @param alpha cutoff value for confidence intervals
 #' @param ... additional arguments to the generic \code{points}
 #'     function
-#' @references Galbraith, R.F., 1990. The radial plot: graphical
-#'     assessment of spread in ages. International Journal of
-#'     Radiation Applications and Instrumentation. Part D. Nuclear
-#'     Tracks and Radiation Measurements, 17(3), pp.207-214.
+#' @seealso \code{\link{peakfit}}, \code{\link{central}}
+#' @references
+#' Galbraith, R.F., 1988. Graphical display of estimates having
+#' differing standard errors. Technometrics, 30(3), pp.271-281.
+#'
+#' Galbraith, R.F., 1990. The radial plot: graphical assessment of
+#' spread in ages. International Journal of Radiation Applications and
+#' Instrumentation. Part D. Nuclear Tracks and Radiation Measurements,
+#' 17(3), pp.207-214.
+#'
+#' Galbraith, R.F. and Laslett, G.M., 1993. Statistical models for
+#' mixed fission track ages. Nuclear Tracks and Radiation
+#' Measurements, 21(4), pp.459-470.
 #' @examples
 #' data(examples)
 #' radialplot(examples$FT1)
+#'
+#' dev.new()
+#' radialplot(examples$LudwigMixture,k='min')
+#'
 #' @rdname radialplot
 #' @export
 radialplot <- function(x,...){ UseMethod("radialplot",x) }
@@ -56,13 +96,14 @@ radialplot <- function(x,...){ UseMethod("radialplot",x) }
 radialplot.default <- function(x,from=NA,to=NA,t0=NA,
                                transformation='log',sigdig=2,
                                show.numbers=FALSE,pch=21,levels=NA,
-                               bg=c("white","red"),title=TRUE,k=0,
-                               markers=NULL,alpha=0.05,...){
+                               clabel="",bg=c("white","red"),
+                               title=TRUE,k=0,markers=NULL,
+                               alpha=0.05,...){
     peaks <- peakfit(x,k=k,sigdig=sigdig)
     markers <- c(markers,peaks$peaks['t',])
     X <- x2zs(x,t0=t0,from=from,to=to,transformation=transformation)
     radial.plot(X,show.numbers=show.numbers,pch=pch,levels=levels,
-                bg=bg,markers=markers,...)
+                clabel=clabel,bg=bg,markers=markers,...)
     if (title) title(radial.title(central(x,alpha=alpha),sigdig=sigdig))
     if (!is.null(peaks$legend))
         graphics::legend('bottomleft',legend=peaks$legend,bty='n')
@@ -74,7 +115,7 @@ radialplot.default <- function(x,from=NA,to=NA,t0=NA,
 radialplot.fissiontracks <- function(x,from=NA,to=NA,t0=NA,
                                      transformation='arcsin',
                                      sigdig=2,show.numbers=FALSE,
-                                     pch=21,levels=NA,
+                                     pch=21,levels=NA,clabel="",
                                      bg=c("white","red"),title=TRUE,
                                      markers=NULL,k=0,exterr=TRUE,
                                      alpha=0.05,...){
@@ -82,8 +123,8 @@ radialplot.fissiontracks <- function(x,from=NA,to=NA,t0=NA,
     markers <- c(markers,peaks$peaks['t',])
     X <- x2zs(x,t0=t0,from=from,to=to,transformation=transformation)
     radial.plot(X,zeta=x$zeta[1],rhoD=x$rhoD[1],
-                show.numbers=show.numbers,pch=pch, levels=levels,
-                bg=bg,markers=markers,...)
+                show.numbers=show.numbers,pch=pch,levels=levels,
+                clabel=clabel,bg=bg,markers=markers,...)
     if (title) title(radial.title(central(x,alpha=alpha),sigdig=sigdig))
     if (!is.null(peaks$legend))
         graphics::legend('bottomleft',legend=peaks$legend,bty='n')
@@ -125,8 +166,9 @@ radialplot.UPb <- function(x,from=NA,to=NA,t0=NA,
                            transformation='log',type=4,
                            cutoff.76=1100,cutoff.disc=c(-15,5),
                            show.numbers=FALSE,pch=21,levels=NA,
-                           bg=c("white","red"),markers=NULL,k=0,
-                           exterr=TRUE,common.Pb=0,alpha=0.05,...){
+                           clabel="",bg=c("white","red"),
+                           markers=NULL,k=0,exterr=TRUE,common.Pb=0,
+                           alpha=0.05,...){
     if (common.Pb %in% c(1,2,3))
         X <- common.Pb.correction(x,option=common.Pb)
     else
@@ -135,140 +177,149 @@ radialplot.UPb <- function(x,from=NA,to=NA,t0=NA,
                       transformation=transformation,type=type,
                       cutoff.76=cutoff.76,cutoff.disc=cutoff.disc,
                       show.numbers=show.numbers,pch=pch,levels=levels,
-                      bg=bg, markers=markers,k=k,exterr=exterr,
-                      alpha=alpha,...)
+                      clabel=clabel,bg=bg,markers=markers,k=k,
+                      exterr=exterr,alpha=alpha,...)
 }
-#' @param i2i `isochron to intercept': calculates the initial
-#'     (aka `inherited', `excess', or `common') \eqn{^{40}}Ar/\eqn{^{36}}Ar,
-#'     \eqn{^{207}}Pb/\eqn{^{204}}Pb, \eqn{^{87}}Sr/\eqn{^{86}}Sr,
-#'     \eqn{^{143}}Nd/\eqn{^{144}}Nd, \eqn{^{187}}Os/\eqn{^{188}}Os or
-#'     \eqn{^{176}}Hf/\eqn{^{177}}Hf ratio from an isochron
-#'     fit. Setting \code{i2i} to \code{FALSE} uses the default values
-#'     stored in \code{settings('iratio',...)}  or zero (for the Pb-Pb
-#'     method). When applied to data of class \code{ThU}, setting
-#'     \code{i2i} to \code{TRUE} applies a detrital Th-correction.
+#' @param i2i `isochron to intercept': calculates the initial (aka
+#'     `inherited', `excess', or `common')
+#'     \eqn{^{40}}Ar/\eqn{^{36}}Ar, \eqn{^{207}}Pb/\eqn{^{204}}Pb,
+#'     \eqn{^{87}}Sr/\eqn{^{86}}Sr, \eqn{^{143}}Nd/\eqn{^{144}}Nd,
+#'     \eqn{^{187}}Os/\eqn{^{188}}Os or \eqn{^{176}}Hf/\eqn{^{177}}Hf
+#'     ratio from an isochron fit. Setting \code{i2i} to \code{FALSE}
+#'     uses the default values stored in
+#'     \code{settings('iratio',...)}. When applied to data of class
+#'     \code{ThU}, setting \code{i2i} to \code{TRUE} applies a
+#'     detrital Th-correction.
 #' @rdname radialplot
 #' @export
 radialplot.PbPb <- function(x,from=NA,to=NA,t0=NA,
                             transformation='log',show.numbers=FALSE,
-                            pch=21,levels=NA,bg=c("white","red"),
-                            markers=NULL,k=0,exterr=TRUE,i2i=TRUE,
-                            alpha=0.05,...){
-    radialplot_helper(x,from=from,to=to,t0=t0,
+                            pch=21,levels=NA,clabel="",
+                            bg=c("white","red"),markers=NULL,k=0,
+                            exterr=TRUE,common.Pb=1,alpha=0.05,...){
+    if (common.Pb %in% c(1,2,3))
+        X <- common.Pb.correction(x,option=common.Pb)
+    else
+        X <- x
+    radialplot_helper(X,from=from,to=to,t0=t0,
                       transformation=transformation,
                       show.numbers=show.numbers,pch=pch,levels=levels,
-                      bg=bg,markers=markers,k=k,exterr=exterr,
-                      i2i=i2i,alpha=alpha,...)
+                      clabel=clabel,bg=bg,markers=markers,k=k,
+                      exterr=exterr,alpha=alpha,...)
 }
 #' @rdname radialplot
 #' @export
 radialplot.ArAr <- function(x,from=NA,to=NA,t0=NA,
                             transformation='log',show.numbers=FALSE,
-                            pch=21,levels=NA,bg=c("white","red"),
-                            markers=NULL,k=0,exterr=TRUE,i2i=FALSE,
-                            alpha=0.05,...){
+                            pch=21,levels=NA,clabel="",
+                            bg=c("white","red"),markers=NULL,k=0,
+                            exterr=TRUE,i2i=FALSE,alpha=0.05,...){
     radialplot_helper(x,from=from,to=to,t0=t0,
                       transformation=transformation,
                       show.numbers=show.numbers,pch=pch,levels=levels,
-                      bg=bg,markers=markers,k=k,exterr=exterr,
-                      i2i=i2i,alpha=alpha,...)
+                      clabel=clabel,bg=bg,markers=markers,k=k,
+                      exterr=exterr,i2i=i2i,alpha=alpha,...)
 }
 #' @rdname radialplot
 #' @export
 radialplot.UThHe <- function(x,from=NA,to=NA,t0=NA,
                              transformation='log',show.numbers=FALSE,
-                             pch=21,levels=NA,bg=c("white","red"),
-                             markers=NULL,k=0,alpha=0.05,...){
+                             pch=21,levels=NA,clabel="",
+                             bg=c("white","red"),markers=NULL,k=0,
+                             alpha=0.05,...){
     radialplot_helper(x,from=from,to=to,t0=t0,
                       transformation=transformation,
                       show.numbers=show.numbers,pch=pch,levels=levels,
-                      bg=bg,markers=markers,k=k,exterr=FALSE,
-                      alpha=alpha,...)
+                      clabel=clabel,bg=bg,markers=markers,k=k,
+                      exterr=FALSE,alpha=alpha,...)
 }
 #' @rdname radialplot
 #' @export
 radialplot.ReOs <- function(x,from=NA,to=NA,t0=NA,
                             transformation='log',show.numbers=FALSE,
-                            pch=21,levels=NA,bg=c("white","red"),
-                            markers=NULL,k=0,exterr=TRUE,i2i=TRUE,
-                            alpha=0.05,...){
+                            pch=21,levels=NA,clabel="",
+                            bg=c("white","red"),markers=NULL,k=0,
+                            exterr=TRUE,i2i=TRUE,alpha=0.05,...){
     radialplot_helper(x,from=from,to=to,t0=t0,
                       transformation=transformation,
                       show.numbers=show.numbers,pch=pch,levels=levels,
-                      bg=bg,markers=markers,k=k,exterr=exterr,
-                      i2i=i2i,alpha=alpha,...)
+                      clabel=clabel,bg=bg,markers=markers,k=k,
+                      exterr=exterr,i2i=i2i,alpha=alpha,...)
 }
 #' @rdname radialplot
 #' @export
 radialplot.SmNd <- function(x,from=NA,to=NA,t0=NA,
                             transformation='log',show.numbers=FALSE,
-                            pch=21,levels=NA,bg=c("white","red"),
-                            markers=NULL,k=0,exterr=TRUE,i2i=TRUE,
-                            alpha=0.05,...){
+                            pch=21,levels=NA,clabel="",
+                            bg=c("white","red"),markers=NULL,k=0,
+                            exterr=TRUE,i2i=TRUE,alpha=0.05,...){
     radialplot_helper(x,from=from,to=to,t0=t0,
                       transformation=transformation,
                       show.numbers=show.numbers,pch=pch,levels=levels,
-                      bg=bg,markers=markers,k=k,exterr=exterr,
-                      i2i=i2i,alpha=alpha,...)
+                      clabel=clabel,bg=bg,markers=markers,k=k,
+                      exterr=exterr,i2i=i2i,alpha=alpha,...)
 }
 #' @rdname radialplot
 #' @export
 radialplot.RbSr <- function(x,from=NA,to=NA,t0=NA,
                             transformation='log',show.numbers=FALSE,
-                            pch=21,levels=NA,bg=c("white","red"),
-                            markers=NULL,k=0,exterr=TRUE,i2i=TRUE,
-                            alpha=0.05,...){
+                            pch=21,levels=NA,clabel="",
+                            bg=c("white","red"),markers=NULL,k=0,
+                            exterr=TRUE,i2i=TRUE,alpha=0.05,...){
     radialplot_helper(x,from=from,to=to,t0=t0,
                       transformation=transformation,
                       show.numbers=show.numbers,pch=pch,levels=levels,
-                      bg=bg,markers=markers,k=k,exterr=exterr,
-                      i2i=i2i,alpha=alpha,...)
+                      clabel=clabel,bg=bg,markers=markers,k=k,
+                      exterr=exterr,i2i=i2i,alpha=alpha,...)
 }
 #' @rdname radialplot
 #' @export
 radialplot.LuHf <- function(x,from=NA,to=NA,t0=NA,
                             transformation='log',show.numbers=FALSE,
-                            pch=21,levels=NA,bg=c("white","red"),
-                            markers=NULL,k=0,exterr=TRUE,i2i=TRUE,
-                            alpha=0.05,...){
+                            pch=21,levels=NA,clabel="",
+                            bg=c("white","red"),markers=NULL,k=0,
+                            exterr=TRUE,i2i=TRUE,alpha=0.05,...){
     radialplot_helper(x,from=from,to=to,t0=t0,
                       transformation=transformation,
                       show.numbers=show.numbers,pch=pch,levels=levels,
-                      bg=bg,markers=markers,k=k,exterr=exterr,
-                      i2i=i2i,alpha=alpha,...)
+                      clabel=clabel,bg=bg,markers=markers,k=k,
+                      exterr=exterr,i2i=i2i,alpha=alpha,...)
 }
 #' @rdname radialplot
 #' @export
 radialplot.ThU <- function(x,from=NA,to=NA,t0=NA,
                            transformation='log',show.numbers=FALSE,
-                           pch=21,levels=NA,bg=c("white","red"),
-                           markers=NULL,k=0,i2i=TRUE,alpha=0.05,...){
+                           pch=21,levels=NA,clabel="",
+                           bg=c("white","red"),markers=NULL,k=0,
+                           i2i=TRUE,alpha=0.05,...){
     radialplot_helper(x,from=from,to=to,t0=t0,
                       transformation=transformation,
                       show.numbers=show.numbers,pch=pch,levels=levels,
-                      bg=bg,markers=markers,k=k,exterr=FALSE,i2i=i2i,
-                      alpha=alpha,...)
+                      clabel=clabel,bg=bg,markers=markers,k=k,
+                      exterr=FALSE,i2i=i2i,alpha=alpha,...)
 }
 radialplot_helper <- function(x,from=NA,to=NA,t0=NA,
                               transformation='log',type=4,
                               cutoff.76=1100,cutoff.disc=c(-15,5),
                               show.numbers=FALSE,pch=21,levels=NA,
-                              bg=c("white","red"),markers=NULL,k=0,
-                              exterr=TRUE,i2i=FALSE,alpha=0.05,...){
+                              clabel="",bg=c("white","red"),
+                              markers=NULL,k=0,exterr=TRUE,i2i=FALSE,
+                              alpha=0.05,...){
     peaks <- peakfit(x,k=k,exterr=exterr,i2i=i2i,type=type,
                      cutoff.76=cutoff.76,cutoff.disc=cutoff.disc)
     markers <- c(markers,peaks$peaks['t',])
     age2radial(x,from=from,to=to,t0=t0,transformation=transformation,
                type=type,cutoff.76=cutoff.76,cutoff.disc=cutoff.disc,
-               show.numbers=show.numbers,pch=pch,levels=levels,bg=bg,
-               markers=markers,i2i=i2i,alpha=alpha,...)
+               show.numbers=show.numbers,pch=pch,levels=levels,
+               clabel=clabel,bg=bg,markers=markers,i2i=i2i,
+               alpha=alpha,...)
     if (!is.null(peaks$legend))
         graphics::legend('bottomleft',legend=peaks$legend,bty='n')
 }
 
 age2radial <- function(x,from=NA,to=NA,t0=NA,transformation='log',
                        type=4,cutoff.76=1100,cutoff.disc=c(-15,5),
-                       show.numbers=FALSE,pch=21,levels=NA,
+                       show.numbers=FALSE,pch=21,levels=NA,clabel="",
                        bg=c("white","red"),markers=NULL,k=0,
                        i2i=FALSE,alpha=0.05,...){
     if (hasClass(x,'UPb')){
@@ -294,12 +345,12 @@ age2radial <- function(x,from=NA,to=NA,t0=NA,transformation='log',
     radialplot.default(tt,from=from,to=to,t0=t0,
                        transformation=transformation,
                        show.numbers=show.numbers,pch=pch,
-                       levels=levels,bg=bg,markers=markers,
-                       alpha=alpha,...)
+                       levels=levels,clabel=clabel,bg=bg,
+                       markers=markers,alpha=alpha,...)
 }
 
 radial.plot <- function(x,zeta=0,rhoD=0,asprat=3/4,
-                        show.numbers=FALSE,pch=21,levels=NA,
+                        show.numbers=FALSE,levels=NA,clabel="",
                         bg=c('white','red'),markers=NULL,...){
     exM <- radial.scale(x,zeta,rhoD)
     tticks <- get.radial.tticks(x)
@@ -313,19 +364,21 @@ radial.plot <- function(x,zeta=0,rhoD=0,asprat=3/4,
     }
     plot_radial_axes(x)
     ns <- length(x$z)
-    col <- set.ellipse.colours(ns=ns,levels=levels,col=bg)
-    plot_points(x,show.numbers,pch,col,...)
-    colourbar(z=levels,col=bg)
+    cols <- set.ellipse.colours(ns=ns,levels=levels,col=bg)
+    plot_radial_points(x,show.numbers=show.numbers,bg=cols,...)
+    colourbar(z=levels,col=bg,clabel=clabel)
 }
 
-plot_points <- function(x,show.numbers=FALSE,pch=21,bg='white',...){
+plot_radial_points <- function(x,show.numbers=FALSE,bg='white',...){
     rxy <- data2rxry(x)
     rx <- rxy[,1]
     ry <- rxy[,2]
     if (show.numbers) {
         graphics::text(rx,ry,1:length(rx),...)
+    } else if ('pch' %in% names(list(...))){
+        graphics::points(rx,ry,bg=bg,...)
     } else {
-        graphics::points(rx,ry,pch=pch,bg=bg,...)
+        graphics::points(rx,ry,bg=bg,pch=21,...)
     }
 }
 
